@@ -110,7 +110,7 @@
 
 (defun day-of-week (year month day)
   "Day of week calculation using Zeller's Congruence.
-Input: The year y, month m (1 ≤ m ≤ 12) and day d (1 ≤ d ≤ 31).
+Input: The year y, month m (1 <= m <= 12) and day d (1 <= d <= 31).
 Output: n - the day of the week (Sunday = 0, Saturday = 6)."
 
   (when (< month 3)
