@@ -446,7 +446,9 @@
                                    :element-type 'fixnum
                                    :initial-element 0))
   (dotimes (i (length *btree-vector*))
-    (setf (aref *btree-vector* i) (random most-positive-fixnum)))
+    (do ((rand (random most-positive-fixnum) (random most-positive-fixnum)))
+        ((not (find rand *btree-vector* :end i))
+         (setf (aref *btree-vector* i) rand))))
   (setq *btree-vector* (sort *btree-vector* #'<)))
 
 (defun test-btree-vector (len)
